function [event,chan] = eeg_load_scan4_cnt_event(filename)

% eeg_load_scan4_cnt_event - Read Neuroscan 4.x Continuous EEG Events
% 
% eventTable = eeg_load_scan4_cnt_event(fid)
%               
%   fid         -  File identifier
%
%   eventTable  -  structure of event info
%
%   Note: Developed with Scan 4.1 CNT files
%
%   See also: eeg_load_scan4_cnt_data
%

% $Revision: 1.1 $ $Date: 2009/04/28 22:13:52 $

% Licence:  GNU GPL, no express or implied warranties
% History:  2002, Sean.Fitzgibbon@flinders.edu.au
%           06/2002, Darren.Weber_at_radiology.ucsf.edu
%                    adapted to eeg_toolbox
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fid = fopen(filename,'r', 'l');
fseek(fid,370,'bof');
nchannels = fread(fid,1,'ushort');
fseek(fid,900,'bof');
chan = cellstr(deblank(char(fread(fid,[10,nchannels],'10*char',75-10)')));
% h.rev               = fread(fid,12,'char'); 
% h.nextfile          = fread(fid,1,'long');  
% h.prevfile          = fread(fid,1,'ulong'); 
% h.type              = fread(fid,1,'char');  
% h.id                = fread(fid,20,'char');
% h.oper              = fread(fid,20,'char');
% h.doctor            = fread(fid,20,'char');
% h.referral          = fread(fid,20,'char');
% h.hospital          = fread(fid,20,'char');
% h.patient           = fread(fid,20,'char');
% h.age               = fread(fid,1,'short');
% h.sex               = fread(fid,1,'char');
% h.hand              = fread(fid,1,'char');
% h.med               = fread(fid,20, 'char');
% h.category          = fread(fid,20, 'char');
% h.state             = fread(fid,20, 'char');
% h.label             = fread(fid,20, 'char');
% h.date              = fread(fid,10, 'char');
% h.time              = fread(fid,12, 'char');
% h.mean_age          = fread(fid,1,'float');
% h.stdev             = fread(fid,1,'float');
% h.n                 = fread(fid,1,'short');
% h.compfile          = fread(fid,38,'char');
% h.spectwincomp      = fread(fid,1,'float');
% h.meanaccuracy      = fread(fid,1,'float');
% h.meanlatency       = fread(fid,1,'float');
% h.sortfile          = fread(fid,46,'char');
% h.numevents         = fread(fid,1,'int');
% h.compoper          = fread(fid,1,'char');
% h.avgmode           = fread(fid,1,'char');
% h.review            = fread(fid,1,'char');
% h.nsweeps           = fread(fid,1,'ushort');
% h.compsweeps        = fread(fid,1,'ushort');
% h.acceptcnt         = fread(fid,1,'ushort');
% h.rejectcnt         = fread(fid,1,'ushort');
% h.pnts              = fread(fid,1,'ushort');%370
% h.nchannels         = fread(fid,1,'ushort');
% h.avgupdate         = fread(fid,1,'ushort');
% h.domain            = fread(fid,1,'char');
% h.variance          = fread(fid,1,'char');
% h.rate              = fread(fid,1,'ushort'); % A USER CLAIMS THAT SAMPLING RATE CAN BE 
% h.scale             = fread(fid,1,'double'); % FRACTIONAL IN NEUROSCAN WHICH IS 
% h.veogcorrect       = fread(fid,1,'char');   % OBVIOUSLY NOT POSSIBLE HERE (BUG 606)
% h.heogcorrect       = fread(fid,1,'char');
% h.aux1correct       = fread(fid,1,'char');
% h.aux2correct       = fread(fid,1,'char');
% h.veogtrig          = fread(fid,1,'float');
% h.heogtrig          = fread(fid,1,'float');
% h.aux1trig          = fread(fid,1,'float');
% h.aux2trig          = fread(fid,1,'float');
% h.heogchnl          = fread(fid,1,'short');
% h.veogchnl          = fread(fid,1,'short');
% h.aux1chnl          = fread(fid,1,'short');
% h.aux2chnl          = fread(fid,1,'short');
% h.veogdir           = fread(fid,1,'char');
% h.heogdir           = fread(fid,1,'char');
% h.aux1dir           = fread(fid,1,'char');
% h.aux2dir           = fread(fid,1,'char');
% h.veog_n            = fread(fid,1,'short');
% h.heog_n            = fread(fid,1,'short');
% h.aux1_n            = fread(fid,1,'short');
% h.aux2_n            = fread(fid,1,'short');
% h.veogmaxcnt        = fread(fid,1,'short');
% h.heogmaxcnt        = fread(fid,1,'short');
% h.aux1maxcnt        = fread(fid,1,'short');
% h.aux2maxcnt        = fread(fid,1,'short');
% h.veogmethod        = fread(fid,1,'char');
% h.heogmethod        = fread(fid,1,'char');
% h.aux1method        = fread(fid,1,'char');
% h.aux2method        = fread(fid,1,'char');
% h.ampsensitivity    = fread(fid,1,'float');
% h.lowpass           = fread(fid,1,'char');
% h.highpass          = fread(fid,1,'char');
% h.notch             = fread(fid,1,'char');
% h.autoclipadd       = fread(fid,1,'char');
% h.baseline          = fread(fid,1,'char');
% h.offstart          = fread(fid,1,'float');
% h.offstop           = fread(fid,1,'float');
% h.reject            = fread(fid,1,'char');
% h.rejstart          = fread(fid,1,'float');
% h.rejstop           = fread(fid,1,'float');
% h.rejmin            = fread(fid,1,'float');
% h.rejmax            = fread(fid,1,'float');
% h.trigtype          = fread(fid,1,'char');
% h.trigval           = fread(fid,1,'float');
% h.trigchnl          = fread(fid,1,'char');
% h.trigmask          = fread(fid,1,'short');
% h.trigisi           = fread(fid,1,'float');
% h.trigmin           = fread(fid,1,'float');
% h.trigmax           = fread(fid,1,'float');
% h.trigdir           = fread(fid,1,'char');
% h.autoscale         = fread(fid,1,'char');
% h.n2                = fread(fid,1,'short');
% h.dir               = fread(fid,1,'char');
% h.dispmin           = fread(fid,1,'float');
% h.dispmax           = fread(fid,1,'float');
% h.xmin              = fread(fid,1,'float');
% h.xmax              = fread(fid,1,'float');
% h.automin           = fread(fid,1,'float');
% h.automax           = fread(fid,1,'float');
% h.zmin              = fread(fid,1,'float');
% h.zmax              = fread(fid,1,'float');
% h.lowcut            = fread(fid,1,'float');
% h.highcut           = fread(fid,1,'float');
% h.common            = fread(fid,1,'char');
% h.savemode          = fread(fid,1,'char');
% h.manmode           = fread(fid,1,'char');
% h.ref               = fread(fid,10,'char');
% h.rectify           = fread(fid,1,'char');
% h.displayxmin       = fread(fid,1,'float');
% h.displayxmax       = fread(fid,1,'float');
% h.phase             = fread(fid,1,'char');
% h.screen            = fread(fid,16,'char');
% h.calmode           = fread(fid,1,'short');
% h.calmethod         = fread(fid,1,'short');
% h.calupdate         = fread(fid,1,'short');
% h.calbaseline       = fread(fid,1,'short');
% h.calsweeps         = fread(fid,1,'short');
% h.calattenuator     = fread(fid,1,'float');
% h.calpulsevolt      = fread(fid,1,'float');
% h.calpulsestart     = fread(fid,1,'float');
% h.calpulsestop      = fread(fid,1,'float');
% h.calfreq           = fread(fid,1,'float');
% h.taskfile          = fread(fid,34,'char');
% h.seqfile           = fread(fid,34,'char');
% h.spectmethod       = fread(fid,1,'char');
% h.spectscaling      = fread(fid,1,'char');
% h.spectwindow       = fread(fid,1,'char');
% h.spectwinlength    = fread(fid,1,'float');
% h.spectorder        = fread(fid,1,'char');
% h.notchfilter       = fread(fid,1,'char');
% h.headgain          = fread(fid,1,'short');
% h.additionalfiles   = fread(fid,1,'int');
% h.unused            = fread(fid,5,'char');
% h.fspstopmethod     = fread(fid,1,'short');
% h.fspstopmode       = fread(fid,1,'short');
% h.fspfvalue         = fread(fid,1,'float');
% h.fsppoint          = fread(fid,1,'short');
% h.fspblocksize      = fread(fid,1,'short');
% h.fspp1             = fread(fid,1,'ushort');
% h.fspp2             = fread(fid,1,'ushort');
% h.fspalpha          = fread(fid,1,'float');
% h.fspnoise          = fread(fid,1,'float');
% h.fspv1             = fread(fid,1,'short');
% h.montage           = fread(fid,40,'char');
% h.eventfile         = fread(fid,40,'char');
% h.fratio            = fread(fid,1,'float');
% h.minor_rev         = fread(fid,1,'char');
% h.eegupdate         = fread(fid,1,'short');
% h.compressed        = fread(fid,1,'char');
% h.xscale            = fread(fid,1,'float');
% h.yscale            = fread(fid,1,'float');
% h.xsize             = fread(fid,1,'float');
% h.ysize             = fread(fid,1,'float');
% h.acmode            = fread(fid,1,'char');
% h.commonchnl        = fread(fid,1,'uchar');
% h.xtics             = fread(fid,1,'char');
% h.xrange            = fread(fid,1,'char');
% h.ytics             = fread(fid,1,'char');
% h.yrange            = fread(fid,1,'char');
% h.xscalevalue       = fread(fid,1,'float');
% h.xscaleinterval    = fread(fid,1,'float');
% h.yscalevalue       = fread(fid,1,'float');
% h.yscaleinterval    = fread(fid,1,'float');
% h.scaletoolx1       = fread(fid,1,'float');
% h.scaletooly1       = fread(fid,1,'float');
% h.scaletoolx2       = fread(fid,1,'float');
% h.scaletooly2       = fread(fid,1,'float');
% h.port              = fread(fid,1,'short');
% h.numsamples        = fread(fid,1,'ulong');
% h.filterflag        = fread(fid,1,'char');
% h.lowcutoff         = fread(fid,1,'float');
% h.lowpoles          = fread(fid,1,'short');
% h.highcutoff        = fread(fid,1,'float');
% h.highpoles         = fread(fid,1,'short');
% h.filtertype        = fread(fid,1,'char');
% h.filterdomain      = fread(fid,1,'char');
% h.snrflag           = fread(fid,1,'char');
% h.coherenceflag     = fread(fid,1,'char');
% h.continuoustype    = fread(fid,1,'char');
% h.eventtablepos     = fread(fid,1,'ulong');
% h.continuousseconds = fread(fid,1,'float');
% h.channeloffset     = fread(fid,1,'long');
% h.autocorrectflag   = fread(fid,1,'char');
% h.dcthreshold       = fread(fid,1,'uchar');


fseek(fid,886,'bof');           eventPos = fread(fid,1,'long');


fseek(fid,eventPos,'bof');      f.type   = fread(fid,1,'uchar');
                                f.size   = fread(fid,1,'long');
                                f.offset = fread(fid,1,'long');
                                

fseek(fid,f.offset,'cof');


for i = 1:(f.size/19),
    

    f.event(i).stimType   = fread(fid,1,'short');
    

    f.event(i).keyBoard   = fread(fid,1,'char');
    

    f.event(i).keyPad     = fread(fid,1,'bit4');
    

    f.event(i).Accept     = fread(fid,1,'bit4');
    

    f.event(i).offset     = fread(fid,1,'long');
    

    f.event(i).type       = fread(fid,1,'short');
    

    f.event(i).code       = fread(fid,1,'short');
    

    f.event(i).latency    = fread(fid,1,'float');
    

    f.event(i).epochEvent = fread(fid,1,'char');
    

    f.event(i).accept     = fread(fid,1,'char');
    

    f.event(i).accuracy   = fread(fid,1,'char');
    

end
ioff=900+(nchannels*75); %% initial offset : header + electordes desc 
for i=1:length(f.event) 
    f.event(i).offset=(f.event(i).offset-ioff)/(4*nchannels); %% 4 short int end 
    event(i).latency = f.event(i).offset + 1;
    event(i).stim    = f.event(i).stimType;
end     